@@ -1,4 +1,5 @@
 import os
+import re
 
 from django.conf.urls.defaults import *
 
@@ -9,13 +10,13 @@ from sentry.feeds import MessageFeed, SummaryFeed
 SENTRY_ROOT = os.path.dirname(__file__) 
 
 urlpatterns = patterns('',
-    url(r'^_media/(?P<path>.*)$', 'django.views.static.serve',
-        {'document_root': os.path.join(SENTRY_ROOT, 'media')}, name='sentry-media'),
+    # This path is also reflected in conf.STATIC_URL_PREFIX
+    url(r'^_static/(?P<path>.*)$', views.static_media, name='sentry-media'),
 
     # Feeds
 
-    url(r'^feeds/%s/messages.xml$' % KEY, MessageFeed(), name='sentry-feed-messages'),
-    url(r'^feeds/%s/summaries.xml$' % KEY, SummaryFeed(), name='sentry-feed-summaries'),
+    url(r'^feeds/%s/messages.xml$' % re.escape(KEY), MessageFeed(), name='sentry-feed-messages'),
+    url(r'^feeds/%s/summaries.xml$' % re.escape(KEY), SummaryFeed(), name='sentry-feed-summaries'),
 
     # JS and API
 
