@@ -12,7 +12,7 @@ from django.core.context_processors import csrf
 from django.core.urlresolvers import reverse
 from django.db.models import Q
 from django.http import HttpResponse, HttpResponseBadRequest, \
-    HttpResponseForbidden, HttpResponseRedirect, Http404
+    HttpResponseForbidden, HttpResponseRedirect, Http404, HttpResponseNotModified
 from django.shortcuts import render_to_response, get_object_or_404
 from django.template.loader import render_to_string
 from django.utils import simplejson
@@ -234,7 +234,7 @@ def ajax_handler(request):
         group.status = 1
         
         if not request.is_ajax():
-            return HttpResponseRedirect(request.META['HTTP_REFERER'])
+            return HttpResponseRedirect(request.META.get('HTTP_REFERER') or reverse('sentry'))
         
         data = [
             (m.pk, {
@@ -369,4 +369,50 @@ def group_plugin_action(request, group_id, slug):
     response = cls(group_id)(request, group)
     if response:
         return response
-    return HttpResponseRedirect(request.META['HTTP_REFERER'])
+    return HttpResponseRedirect(request.META.get('HTTP_REFERER') or reverse('sentry'))
+
+def static_media(request, path):
+    """
+    Serve static files below a given point in the directory structure.
+    """
+    from django.utils.http import http_date
+    from django.views.static import was_modified_since
+    import mimetypes
+    import os.path
+    import posixpath
+    import stat
+    import urllib
+
+    document_root = os.path.join(conf.ROOT, 'static')
+    
+    path = posixpath.normpath(urllib.unquote(path))
+    path = path.lstrip('/')
+    newpath = ''
+    for part in path.split('/'):
+        if not part:
+            # Strip empty path components.
+            continue
+        drive, part = os.path.splitdrive(part)
+        head, part = os.path.split(part)
+        if part in (os.curdir, os.pardir):
+            # Strip '.' and '..' in path.
+            continue
+        newpath = os.path.join(newpath, part).replace('\\', '/')
+    if newpath and path != newpath:
+        return HttpResponseRedirect(newpath)
+    fullpath = os.path.join(document_root, newpath)
+    if os.path.isdir(fullpath):
+        raise Http404("Directory indexes are not allowed here.")
+    if not os.path.exists(fullpath):
+        raise Http404('"%s" does not exist' % fullpath)
+    # Respect the If-Modified-Since header.
+    statobj = os.stat(fullpath)
+    mimetype = mimetypes.guess_type(fullpath)[0] or 'application/octet-stream'
+    if not was_modified_since(request.META.get('HTTP_IF_MODIFIED_SINCE'),
+                              statobj[stat.ST_MTIME], statobj[stat.ST_SIZE]):
+        return HttpResponseNotModified(mimetype=mimetype)
+    contents = open(fullpath, 'rb').read()
+    response = HttpResponse(contents, mimetype=mimetype)
+    response["Last-Modified"] = http_date(statobj[stat.ST_MTIME])
+    response["Content-Length"] = len(contents)
+    return response
\ No newline at end of file
